using System;
using System.Data;
using System.Data.SqlClient;
using Foxit.PDF;
using Foxit.PDF.PageElements;

namespace Web_CSharp.GeneratorExamples.Generator
{
    public partial class MailingLabels : System.Web.UI.Page
    {
        //////////////////////////////////////////////////
        // Begin Setting Region
        // This settings are for Avery Label number 5160. Modify the settings below based on your label number

        // Set page dimensions
        static int topMargin = 36;
        static int bottomMargin = 36;
        static float rightMargin = 13.5f;
        static float leftMargin = 13.5f;

        // Set the number of labels per page
        static int maximumColumns = 3;
        static int maximumRows = 10;

        // Set the spacing between the labels
        static int horizontalSpace = 9;
        static int verticalSpace = 0;

        // These margins are on the labels themsleves
        static int labelTopBottomMargin = 5;
        static int labelLeftRightMargin = 15;

        // End Setting Region
        //////////////////////////////////////////////////

        Foxit.PDF.Document document;
        Foxit.PDF.Page page;
        float currentColumn, currentRow, labelWidth, labelHeight;
        string companyName;
        string contactName;
        string phone;
        string fax;
        SqlConnection connection;
        SqlCommand command;
        SqlDataReader dataReader;
        String SQL;

        protected void Page_Load(object sender, System.EventArgs e)
        {
            // Put user code to initialize the page here
            document = new Foxit.PDF.Document();
            page = new Foxit.PDF.Page(PageSize.Letter, PageOrientation.Portrait);
            document.Creator = "MailingLabels.aspx";
            document.Author = "Foxit Software";
            document.Title = "Mailing Labels";

            // Entrypoint for the labels
            currentRow = 1;
            currentColumn = 1;
            connection = new SqlConnection(System.Configuration.ConfigurationSettings.AppSettings["NorthWindConnectionString"]);
            connection.Open();
            SQL = "Select CompanyName, ContactName, Phone, Fax FROM Customers";
            command = new SqlCommand(SQL, connection);
            dataReader = command.ExecuteReader();

            // Loop over the RecordSet and add each label
            while (dataReader.Read())
            {
                companyName = SafeDBNull(dataReader["CompanyName"]);
                contactName = SafeDBNull(dataReader["ContactName"]);
                phone = SafeDBNull(dataReader["Phone"]);
                fax = SafeDBNull(dataReader["Fax"]);
                AddLabel();
            }
            if (page.Elements.Count > 0)
                document.Pages.Add(page);

            // Outputs the document to the current web page
            document.DrawToWeb("Labels.pdf");
            Visible = false;
        }

        private float FindLabelHeight()
        {
            return (page.Dimensions.Height - (page.Dimensions.TopMargin + page.Dimensions.BottomMargin) - ((maximumRows - 1) * verticalSpace)) / maximumRows;
        }

        private float FindLabelWidth()
        {
            return (page.Dimensions.Width - (page.Dimensions.RightMargin + page.Dimensions.LeftMargin) - ((maximumColumns - 1) * horizontalSpace)) / maximumColumns;
        }

        private void AddLabel()
        {
            // Add a new page if you are beyond the maximum Rows
            if (currentRow == maximumRows + 1)
            {
                document.Pages.Add(page);
                currentRow = 1;
            }

            // Determines if the the label belongs in the first row or first column of the page
            if (currentColumn > 1 & currentRow > 1)
            {
                AddToPage();
            }
            else if (currentColumn > 1 & currentRow == 1)
            {
                AddToFirstRow();
            }
            else if (currentColumn == 1 & currentRow > 1)
            {
                AddToFirstColumn();
            }
            else
            {
                page = new Foxit.PDF.Page(PageSize.Letter, PageOrientation.Portrait);
                page.Dimensions.TopMargin = topMargin;
                page.Dimensions.BottomMargin = bottomMargin;
                page.Dimensions.RightMargin = rightMargin;
                page.Dimensions.LeftMargin = leftMargin;
                labelWidth = FindLabelWidth();
                labelHeight = FindLabelHeight();
                AddToFirstRowColumn();
            }

            // Incremment your row if you are beyond the maximum columns
            if (currentColumn == maximumColumns + 1)
            {
                currentRow = currentRow + 1;
                currentColumn = 1;
            }
        }

        // Adds the label on at least row 2 column 2 of the page
        private void AddToPage()
        {
            float x;
            float y;
            y = (currentRow - 1) * (labelHeight + verticalSpace);
            x = (currentColumn - 1) * (labelWidth + horizontalSpace);
            AddLabelInfo(x, y);
            currentColumn = currentColumn + 1;
        }

        // Adds the label on the first row of labels
        private void AddToFirstRow()
        {
            float x;
            float y;
            y = 0;
            x = (currentColumn - 1) * (labelWidth + horizontalSpace);
            AddLabelInfo(x, y);
            currentColumn = currentColumn + 1;
        }

        // Adds the label to the First column of labels
        private void AddToFirstColumn()
        {
            float x;
            float y;
            y = (currentRow - 1) * (labelHeight + verticalSpace);
            x = 0;
            AddLabelInfo(x, y);
            currentColumn = currentColumn + 1;
        }

        // Adds only the first label of every page (row 1 column 1)
        private void AddToFirstRowColumn()
        {
            float x;
            float y;
            y = 0;
            x = 0;
            AddLabelInfo(x, y);
            currentColumn = currentColumn + 1;
        }

        // This is where you format the look of each label
        private void AddLabelInfo(float x, float y)
        {
            TextArea txt1 = new TextArea(companyName, x + labelLeftRightMargin, y + labelTopBottomMargin, labelWidth - (labelLeftRightMargin * 2), 11, Font.TimesRoman, 11);
            TextArea txt2 = new TextArea(contactName, x + labelLeftRightMargin, y + labelTopBottomMargin + 12, labelWidth - (labelLeftRightMargin * 2), 11, Font.TimesRoman, 11);
            TextArea txt3 = new TextArea(phone, x + labelLeftRightMargin, y + labelTopBottomMargin + 24, labelWidth - (labelLeftRightMargin * 2), 11, Font.TimesRoman, 11);
            TextArea txt4 = new TextArea(fax, x + labelLeftRightMargin, y + labelTopBottomMargin + 36, labelWidth - (labelLeftRightMargin * 2), 11, Font.TimesRoman, 11);
            page.Elements.Add(txt1);
            page.Elements.Add(txt2);
            page.Elements.Add(txt3);
            page.Elements.Add(txt4);
        }

        private string SafeDBNull(object value)
        {
            if (value is DBNull)
                return String.Empty;
            else
                return (string)value;
        }

        #region Web Form Designer generated code
        override protected void OnInit(EventArgs e)
        {
            //
            // CODEGEN: This call is required by the ASP.NET Web Form Designer.
            //
            InitializeComponent();
            base.OnInit(e);
        }

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
        }
        #endregion
    }
}
