using System;
using System.Data;
using System.Data.SqlClient;
using Foxit.PDF;
using Foxit.PDF.IO;
using Foxit.PDF.Text;
using Foxit.PDF.PageElements;

namespace Web_CSharp.GeneratorExamples
{
	public partial class TableReport : System.Web.UI.Page
	{
		static string dBConnString =
			System.Configuration.ConfigurationSettings.AppSettings["NorthWindConnectionString"];

		protected void Page_Load(object sender, System.EventArgs e)
		{
			// Create a document and set it's properties
			Foxit.PDF.Document document = new Foxit.PDF.Document();
			document.Creator = "TableReport.aspx";
			document.Author = "Foxit Software";
			document.Title = "Table Report";

			// Establises connection to the database
			SqlConnection connection = GetOpenDBConn();
			SqlDataReader data = GetContactListData( connection );
			
			//Create a Table and set it's properties
			Table table = new Table( 0, 0, 512, 676, Foxit.PDF.Font.Helvetica, 12 );
            table.Border.Width = 1f;
            table.CellDefault.Border.Width = 1f;
            table.Border.Color = Grayscale.Black;
            table.RepeatColumnHeaderCount = 1;
            table.RepeatRowHeaderCount = 1;
			
			// Builds the report
			BuildTable( data, table );
			int currentRow = 0;
			int currentColumn = 0;
			do
			{
				currentRow++;
				currentColumn = 1;
				AddTableToPage( document, table, currentRow, currentColumn );
				Table overflowTable = table.GetOverflowColumns();
				do
				{
					currentColumn++;
					AddTableToPage( document, overflowTable, currentRow, currentColumn );
					overflowTable = overflowTable.GetOverflowColumns();
				} while ( overflowTable != null );
				table = table.GetOverflowRows();
			} while ( table != null );

			// Cleans up database connections
			data.Close();
			connection.Close();
			
			// Outputs the SimpleReport to the current web page
			document.DrawToWeb( "TableExample.pdf" );
		}

		private void AddTableToPage( Document document, Table table, int currentRow, int currentColumn )
		{
			Page page = new Page( PageSize.Letter );
			if( table != null )
				page.Elements.Add( table );
			page.Elements.Add( new Label( "(" + currentRow + "," + currentColumn + ")", 0, page.Dimensions.Body.Height - 12, page.Dimensions.Body.Width, 12, Font.Helvetica, 12, TextAlign.Center ) );
			document.Pages.Add( page );
		}

		private void BuildTable( SqlDataReader data, Table table )
		{
			CreateColumns( table );
			CreateRowHeadings( table );
			while( data.Read() )
				CreateRow( table, data );
		}

		private void CreateRowHeadings( Table table )
		{
			Row row = table.Rows.Add( 40, Font.TimesBold, 12, RgbColor.Black, RgbColor.LightGrey );
            row.CellDefault.Align = TextAlign.Center;
            row.CellDefault.VAlign = VAlign.Top;
            row.Cells.Add("ID");
			row.Cells.Add( "Product Name" );
			row.Cells.Add( "Supplier ID" );
			row.Cells.Add( "Category ID" );
			row.Cells.Add( "Quantity Per Unit" );
			row.Cells.Add( "Unit Price" );
			row.Cells.Add( "Unit In Stock" );
			row.Cells.Add( "Units On Order" );
			row.Cells.Add( "Reorder Level" );
			row.Cells.Add( "Discontinued" );
		}

		private void CreateRow( Table table, SqlDataReader data )
		{
			Row row = table.Rows.Add( 20 );
			row.Cells.Add( data.GetInt32(0).ToString( ), Font.Helvetica, 12, RgbColor.Black, RgbColor.LightGrey, 1 );
			row.Cells.Add( data.GetString(1) );
			row.Cells.Add( data.GetInt32(2).ToString( ) );
			row.Cells.Add( data.GetInt32(3).ToString( ) );
			row.Cells.Add( data.GetString(4) );
			row.Cells.Add( data.GetDecimal(5).ToString( "$0.00" ) );
			row.Cells.Add( data.GetInt16(6).ToString( ) );
			row.Cells.Add( data.GetInt16(7).ToString( ) );
			row.Cells.Add( data.GetInt16(8).ToString( ) );
			row.Cells.Add( data.GetBoolean(9).ToString( ) );
		}

		private void CreateColumns( Table table )
		{
			table.Columns.Add( 25 );
			table.Columns.Add( 150 );
			table.Columns.Add( 90 );
			table.Columns.Add( 90 );
			table.Columns.Add( 120 );
			table.Columns.Add( 60 );
			table.Columns.Add( 90 );
			table.Columns.Add( 90 );
			table.Columns.Add( 90 );
			table.Columns.Add( 90 );
		}

		private SqlConnection GetOpenDBConn()
		{
			// Creates and opens a database connection
			SqlConnection connection = new SqlConnection( dBConnString );
			connection.Open();
			return connection;
		}

		private SqlDataReader GetContactListData( SqlConnection connection )
		{
			// Creates a DataReader for the report
			SqlCommand command = connection.CreateCommand();
			command.CommandText = "SELECT * FROM Products";
			SqlDataReader dataReader = command.ExecuteReader();
			return dataReader;
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
		}
		#endregion
	}
}
